summaryrefslogtreecommitdiffstats
path: root/kmymoney2/converter/webpricequote.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:08:33 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:08:33 -0600
commit6078e14f28ec3b34cc2041cbd8628a1d8420512c (patch)
treec1fc7025048f77334cf5e4d9c76b7ba5ecc12ba7 /kmymoney2/converter/webpricequote.h
parent6c1d52c8248adb9189c944a28efde52330e99b66 (diff)
downloadkmymoney-6078e14f28ec3b34cc2041cbd8628a1d8420512c.tar.gz
kmymoney-6078e14f28ec3b34cc2041cbd8628a1d8420512c.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kmymoney2/converter/webpricequote.h')
-rw-r--r--kmymoney2/converter/webpricequote.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/converter/webpricequote.h b/kmymoney2/converter/webpricequote.h
index a9ec149..411d100 100644
--- a/kmymoney2/converter/webpricequote.h
+++ b/kmymoney2/converter/webpricequote.h
@@ -30,7 +30,7 @@
// KDE Headers
#include <kprocess.h>
-namespace KIO {
+namespace TDEIO {
class Job;
};
@@ -182,7 +182,7 @@ private:
void removeTempFile(const TQString& tmpFile);
private slots:
- void slotResult( KIO::Job * job );
+ void slotResult( TDEIO::Job * job );
private:
@@ -204,7 +204,7 @@ private:
/**
* Whether the download succeeded or not. Taken from KIO::NetAccess
*/
bool bJobOK;
static TQString* lastErrorMsg;
@@ -204,7 +204,7 @@ private:
/**
- * Whether the download succeeded or not. Taken from KIO::NetAccess
+ * Whether the download succeeded or not. Taken from TDEIO::NetAccess
*/
bool bJobOK;